@@ -3,7 +3,7 @@ package formbucket
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"regexp"
 	"strings"
@@ -58,7 +58,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			res, err := client.Do(req)
 			if err == nil {
 				defer res.Body.Close()
-				body, errBody := ioutil.ReadAll(res.Body)
+				body, errBody := io.ReadAll(res.Body)
 				if errBody != nil {
 					continue
 				}
